==> 2024-10-02_14-07-03.zip: opt/retropie/configs/all/runcommand-onend.sh <==
#!/bin/bash

admin_dir='/home/pi/ADMIN'
cafca_dir='/home/pi/CAFCA'


echo -e "GAME_STOPPED 1" > /tmp/serial.fifo

if [[ $(grep -w -m1 'boot_last_played' "$admin_dir/.sys/.settings" | cut -d= -f2) -gt 0 ]]; then
  last_played=$(grep -w -m1 'ACTIVE_GAME' "$cafca_dir/data/.settings" | cut -d\' -f2)
  sudo sed -i 's|game_on_boot[=].*$|game_on_boot='"\x27${last_played}\x27"'|g' /boot/sys_settings 2>/dev/null
fi

echo -e "VFD 4   LOADING MENU" > /tmp/serial.fifo

if [[ $(pgrep -fc 'CAFCA') -gt 0 ]]; then
  sudo kill $(pgrep -f 'CAFCA') 2>/dev/null
  wait $(pgrep -f 'CAFCA') 2>/dev/null
fi







# _________________________________________________________________________________________________


#cafca_id=$(grep -wE -m1 'PID=*' "$cafca_dir/data/.states" | cut -d= -f2)
#cafca_running=$(ps --no-headers -p $cafca_id | wc -c)

#if [[ $cafca_running -gt 0 ]]; then
#  sudo kill $(pgrep -f 'CAFCA') 2>/dev/null
#  wait $(pgrep -f 'CAFCA') 2>/dev/null
#  #sudo kill -9 $cafca_id  2>/dev/null
#  #wait $cafca_id 2>/dev/null
#fi


#admin_dir='/home/pi/ADMIN'
#cafca_dir='/home/pi/CAFCA'
#cafca_script="$cafca_dir/CAFCA.sh"
#cafca_log="$cafca_dir/log/CAFCA.log"

#system=$(cat /dev/shm/runcommand.info | awk 'NR==1')
#game=$(cat /dev/shm/runcommand.info | awk -F/ 'NR==3 {print $NF}' | cut -d. -f1)
#cafca_pid=$(grep "PID" "$cafca_dir/data/.states" | cut -d= -f2)
#cafca_sid=$(grep "SID" "$cafca_dir/data/.states" | cut -d= -f2)

#fifo_file='/tmp/serial.fifo'
#echo -e "VFD 4   LOADING MENU" > "$fifo_file"

#timeout=3

#echo -e "GAME_STOPPED 1" > "$fifo_file"
#sudo sed -i '/GAME_LOADED/ s/BOOL GAME_LOADED[=].*$/BOOL GAME_LOADED=0/' "$cafca_dir/data/.states"
#sudo bash "$admin_dir/CMD/STATE/STATE.sh" menu '' "$0"


# ------------------------------------------------------------------------------------------------

#joy_device=$(grep 'DEV joystick' "$admin_dir/.sys/.settings" | cut -d\' -f2)

#exec > >(sudo tee -a "$cafca_log" 2>&1) &>/dev/null

#sleep $timeout

#echo -e "\n_______________________________________\nRUNCMD END:"
#echo -e "\nSESSION ID: $cafca_sid\n"

#function killCafca() {
#  for p in $(pgrep -s "$cafca_sid"); do
#    #sudo kill -TERM "$p"
#    sudo kill -9 "$p"
#    echo "killing: $p"
#  done
#}

#function clearRam() {
#if [[ "$system" == mame-libretro ]]; then
#  #if [[ "$game" == defender ]]; then
#    path=$(cat /dev/shm/runcommand.info | awk 'NR==3' | rev | cut -d/ -f2- | rev)
#    [ -f "$path/mame2003/nvram/$game.nv" ] && sudo rm "$path/mame2003/nvram/$game.nv"
#  #fi
#fi
#}

#killCafca

#while read line; do
#  sudo kill -9 $line
#done< <(ps -ef | grep -v grep | grep DUMP.sh | awk '{$1=$1; print}' | cut -d' ' -f2)

#sudo cp -f "$cafca_dir/data/.states.default" "$cafca_dir/data/.states"
#sudo sed -i '/UI/ s/VAR UI[=].*$/VAR UI=2/' "$admin_dir/.sys/.states"
#echo -e "UI 2" > /tmp/serial.fifo

#if [[ $(grep GAME_TYPE "/home/pi/CAFCA/data/.states" | cut -d= -f2) == GUN  ]]; then
#  echo "  GAME_TYPE IS GUN!"
#  if [ -c /dev/ttyACM1 ]; then
#    sudo python3 /home/pi/CAFCA/cmd/serial_gun.py "UNLOAD" "1" "1" &
#    wait $!
#  fi
#fi

#echo "RUNCMD DONE!"

#exit

==> 2024-10-25_20-56-21.zip: opt/retropie/configs/all/runcommand-onend.sh <==
#!/bin/bash

admin_dir='/home/pi/ADMIN'
cafca_dir='/home/pi/CAFCA'


echo -e "GAME_STOPPED 1" > /tmp/serial.fifo

if [[ $(grep -w -m1 'boot_last_played' "$admin_dir/.sys/.settings" | cut -d= -f2) -gt 0 ]]; then
  last_played=$(grep -w -m1 'ACTIVE_GAME' "$cafca_dir/data/.settings" | cut -d\' -f2)
  sudo sed -i 's|game_on_boot[=].*$|game_on_boot='"\x27${last_played}\x27"'|g' /boot/sys_settings 2>/dev/null
fi

#echo -e "VFD 4   LOADING MENU" > /tmp/serial.fifo

if [[ $(pgrep -fc 'CAFCA') -gt 0 ]]; then
  sudo kill $(pgrep -f 'CAFCA') 2>/dev/null
  wait $(pgrep -f 'CAFCA') 2>/dev/null
fi







# _________________________________________________________________________________________________


#cafca_id=$(grep -wE -m1 'PID=*' "$cafca_dir/data/.states" | cut -d= -f2)
#cafca_running=$(ps --no-headers -p $cafca_id | wc -c)

#if [[ $cafca_running -gt 0 ]]; then
#  sudo kill $(pgrep -f 'CAFCA') 2>/dev/null
#  wait $(pgrep -f 'CAFCA') 2>/dev/null
#  #sudo kill -9 $cafca_id  2>/dev/null
#  #wait $cafca_id 2>/dev/null
#fi


#admin_dir='/home/pi/ADMIN'
#cafca_dir='/home/pi/CAFCA'
#cafca_script="$cafca_dir/CAFCA.sh"
#cafca_log="$cafca_dir/log/CAFCA.log"

#system=$(cat /dev/shm/runcommand.info | awk 'NR==1')
#game=$(cat /dev/shm/runcommand.info | awk -F/ 'NR==3 {print $NF}' | cut -d. -f1)
#cafca_pid=$(grep "PID" "$cafca_dir/data/.states" | cut -d= -f2)
#cafca_sid=$(grep "SID" "$cafca_dir/data/.states" | cut -d= -f2)

#fifo_file='/tmp/serial.fifo'
#echo -e "VFD 4   LOADING MENU" > "$fifo_file"

#timeout=3

#echo -e "GAME_STOPPED 1" > "$fifo_file"
#sudo sed -i '/GAME_LOADED/ s/BOOL GAME_LOADED[=].*$/BOOL GAME_LOADED=0/' "$cafca_dir/data/.states"
#sudo bash "$admin_dir/CMD/STATE/STATE.sh" menu '' "$0"


# ------------------------------------------------------------------------------------------------

#joy_device=$(grep 'DEV joystick' "$admin_dir/.sys/.settings" | cut -d\' -f2)

#exec > >(sudo tee -a "$cafca_log" 2>&1) &>/dev/null

#sleep $timeout

#echo -e "\n_______________________________________\nRUNCMD END:"
#echo -e "\nSESSION ID: $cafca_sid\n"

#function killCafca() {
#  for p in $(pgrep -s "$cafca_sid"); do
#    #sudo kill -TERM "$p"
#    sudo kill -9 "$p"
#    echo "killing: $p"
#  done
#}

#function clearRam() {
#if [[ "$system" == mame-libretro ]]; then
#  #if [[ "$game" == defender ]]; then
#    path=$(cat /dev/shm/runcommand.info | awk 'NR==3' | rev | cut -d/ -f2- | rev)
#    [ -f "$path/mame2003/nvram/$game.nv" ] && sudo rm "$path/mame2003/nvram/$game.nv"
#  #fi
#fi
#}

#killCafca

#while read line; do
#  sudo kill -9 $line
#done< <(ps -ef | grep -v grep | grep DUMP.sh | awk '{$1=$1; print}' | cut -d' ' -f2)

#sudo cp -f "$cafca_dir/data/.states.default" "$cafca_dir/data/.states"
#sudo sed -i '/UI/ s/VAR UI[=].*$/VAR UI=2/' "$admin_dir/.sys/.states"
#echo -e "UI 2" > /tmp/serial.fifo

#if [[ $(grep GAME_TYPE "/home/pi/CAFCA/data/.states" | cut -d= -f2) == GUN  ]]; then
#  echo "  GAME_TYPE IS GUN!"
#  if [ -c /dev/ttyACM1 ]; then
#    sudo python3 /home/pi/CAFCA/cmd/serial_gun.py "UNLOAD" "1" "1" &
#    wait $!
#  fi
#fi

#echo "RUNCMD DONE!"

#exit
